@@ -1,18 +1,16 @@
-/* $Id$ */
-
 /***
   This file is part of avahi.
- 
+
   avahi is free software; you can redistribute it and/or modify it
   under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 2.1 of the
   License, or (at your option) any later version.
- 
+
   avahi is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
   Public License for more details.
- 
+
   You should have received a copy of the GNU Lesser General Public
   License along with avahi; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
@@ -38,7 +36,7 @@ AvahiStringList*avahi_string_list_add_anonymous(AvahiStringList *l, size_t size)
 
     if (!(n = avahi_malloc(sizeof(AvahiStringList) + size)))
         return NULL;
-    
+
     n->next = l;
     n->size = size;
 
@@ -71,14 +69,14 @@ AvahiStringList *avahi_string_list_add(AvahiStringList *l, const char *text) {
 int avahi_string_list_parse(const void* data, size_t size, AvahiStringList **ret) {
     const uint8_t *c;
     AvahiStringList *r = NULL;
-    
+
     assert(data);
     assert(ret);
 
     c = data;
     while (size > 0) {
         size_t k;
-        
+
         k = *(c++);
         size--;
 
@@ -88,18 +86,18 @@ int avahi_string_list_parse(const void* data, size_t size, AvahiStringList **ret
         if (k > 0) { /* Ignore empty strings */
             AvahiStringList *n;
 
-            if (!(n = avahi_string_list_add_arbitrary(r, c, k)))  
+            if (!(n = avahi_string_list_add_arbitrary(r, c, k)))
                 goto fail; /* OOM */
 
             r = n;
         }
-            
+
         c += k;
         size -= k;
     }
 
     *ret = r;
-    
+
     return 0;
 
 fail:
@@ -130,38 +128,98 @@ AvahiStringList* avahi_string_list_reverse(AvahiStringList *l) {
     return r;
 }
 
+/**
+ * This routine is used for both human- and machine-readable output of
+ * TXT records. As such it must cope with escaping, in order to allow
+ * machines to reconstruct the original data.
+ *
+ * AFAIK no RFC specifies syntax for TXT data other than raw binary,
+ * though presumably zonefile syntax would make sense:
+ *
+ *   - RFC 1035 says that TXT records contain `<character-string>`s, and section
+ *     5 says:
+ *
+ *       <character-string> is expressed in one or two ways: as a contiguous set
+ *       of characters without interior spaces, or as a string beginning with a "
+ *       and ending with a ".  Inside a " delimited string any character can
+ *       occur, except for a " itself, which must be quoted using \ (back slash).
+ *
+ *     This omits escaping of backslashes (!).
+ *
+ *   - RFC 1034 doesn't say anything relevant.
+ *
+ *   - RFC 1464 suggests a specific encoding of information within a TXT
+ *     record but does not discuss formatting of TXT records in
+ *     general.
+ *
+ * In order to also escape newlines, which interfere with line-by-line
+ * machine processing of records, this routine:
+ *
+ *   - escapes >>> " <<< to >>> \" <<<
+ *   - escapes >>> \ <<< to >>> \\ <<<
+ *   - escapes bytes less than 32 to backslash-prefixed 3-digit DECIMAL form
+ */
 char* avahi_string_list_to_string(AvahiStringList *l) {
     AvahiStringList *n;
     size_t s = 0;
-    char *t, *e;
+    char *p, *t, *e;
 
     for (n = l; n; n = n->next) {
         if (n != l)
-            s ++;
+            s ++; /* for the inter-string separating space */
 
-        s += n->size+2;
+        for (p = (char*) n->text; ((size_t) (p - (char*) n->text) < n->size); p++) {
+            switch (*p) {
+              case '"':
+              case '\\':
+                  s += 2;
+                  break;
+              default:
+                  if (*p < 32) {
+                      s += 4;
+                  } else {
+                      s ++;
+                      break;
+                  }
+            }
+        }
+        s += 2; /* for the leading and trailing double-quotes */
     }
 
-    if (!(t = e = avahi_new(char, s+1)))
+    if (!(t = e = avahi_new(char, s+1))) /* plus one for the trailing NUL */
         return NULL;
 
     l = avahi_string_list_reverse(l);
-    
+
     for (n = l; n; n = n->next) {
         if (n != l)
             *(e++) = ' ';
 
         *(e++) = '"';
-        strncpy(e, (char*) n->text, n->size);
-        e[n->size] = 0;
-        e = strchr(e, 0);
+        for (p = (char*) n->text; ((size_t) (p - (char*) n->text) < n->size); p++) {
+            switch (*p) {
+              case '"':
+              case '\\':
+                  *(e++) = '\\';
+                  /* FALL THROUGH */
+              default:
+                  if (*p < 32) {
+                      *(e++) = '\\';
+                      *(e++) = '0' + (char)  ((uint8_t) *p / 100);
+                      *(e++) = '0' + (char) (((uint8_t) *p / 10) % 10);
+                      *(e++) = '0' + (char)  ((uint8_t) *p % 10);
+                  } else {
+                      *(e++) = *p;
+                  }
+            }
+        }
         *(e++) = '"';
 
         assert(e);
     }
 
     l = avahi_string_list_reverse(l);
-    
+
     *e = 0;
 
     return t;
@@ -176,18 +234,18 @@ size_t avahi_string_list_serialize(AvahiStringList *l, void *data, size_t size)
 
         l = avahi_string_list_reverse(l);
         c = data;
-        
+
         for (n = l; size > 1 && n; n = n->next) {
             size_t k;
 
             if ((k = n->size) == 0)
                 /* Skip empty strings */
                 continue;
-            
+
             if (k > 255)
                 /* Truncate strings at 255 characters */
                 k = 255;
-            
+
             if (k > size-1)
                 /* Make sure this string fits in */
                 k = size-1;
@@ -195,15 +253,15 @@ size_t avahi_string_list_serialize(AvahiStringList *l, void *data, size_t size)
             *(c++) = (uint8_t) k;
             memcpy(c, n->text, k);
             c += k;
-            
+
             used += 1 + k;
             size -= 1 + k;
         }
-        
+
         l = avahi_string_list_reverse(l);
 
         if (used == 0 && size > 0) {
-        
+
             /* Empty lists are treated specially. To comply with
              * section 6.1 of the DNS-SD spec, we return a single
              * empty string (i.e. a NUL byte)*/
@@ -211,19 +269,19 @@ size_t avahi_string_list_serialize(AvahiStringList *l, void *data, size_t size)
             *(uint8_t*) data = 0;
             used = 1;
         }
-            
+
     } else {
         AvahiStringList *n;
 
         for (n = l; n; n = n->next) {
             size_t k;
-            
+
             if ((k = n->size) == 0)
                 continue;
-            
+
             if (k > 255)
                 k = 255;
-            
+
             used += 1+k;
         }
 
@@ -260,7 +318,7 @@ AvahiStringList *avahi_string_list_add_many(AvahiStringList *r, ...) {
     va_start(va, r);
     r = avahi_string_list_add_many_va(r, va);
     va_end(va);
-    
+
     return r;
 }
 
@@ -328,7 +386,7 @@ unsigned avahi_string_list_length(const AvahiStringList *l) {
 AvahiStringList *avahi_string_list_add_vprintf(AvahiStringList *l, const char *format, va_list va) {
     size_t len = 80;
     AvahiStringList *r;
-    
+
     assert(format);
 
     if (!(r = avahi_malloc(sizeof(AvahiStringList) + len)))
@@ -338,7 +396,7 @@ AvahiStringList *avahi_string_list_add_vprintf(AvahiStringList *l, const char *f
         int n;
         AvahiStringList *nr;
         va_list va2;
-        
+
         va_copy(va2, va);
         n = vsnprintf((char*) r->text, len, format, va2);
         va_end(va2);
@@ -358,28 +416,28 @@ AvahiStringList *avahi_string_list_add_vprintf(AvahiStringList *l, const char *f
 
         r = nr;
     }
-    
+
     r->next = l;
-    r->size = strlen((char*) r->text); 
+    r->size = strlen((char*) r->text);
 
     return r;
 }
 
 AvahiStringList *avahi_string_list_add_printf(AvahiStringList *l, const char *format, ...) {
     va_list va;
-    
+
     assert(format);
 
     va_start(va, format);
     l  = avahi_string_list_add_vprintf(l, format, va);
     va_end(va);
 
-    return l;    
+    return l;
 }
 
 AvahiStringList *avahi_string_list_find(AvahiStringList *l, const char *key) {
     size_t n;
-    
+
     assert(key);
     n = strlen(key);
 
@@ -411,7 +469,7 @@ AvahiStringList *avahi_string_list_add_pair_arbitrary(AvahiStringList *l, const
         return avahi_string_list_add(l, key);
 
     n = strlen(key);
-    
+
     if (!(l = avahi_string_list_add_anonymous(l, n + 1 + size)))
         return NULL;
 
@@ -424,12 +482,12 @@ AvahiStringList *avahi_string_list_add_pair_arbitrary(AvahiStringList *l, const
 
 int avahi_string_list_get_pair(AvahiStringList *l, char **key, char **value, size_t *size) {
     char *e;
-    
+
     assert(l);
 
     if (!(e = memchr(l->text, '=', l->size))) {
 
-        if (key) 
+        if (key)
             if (!(*key = avahi_strdup((char*) l->text)))
                 return -1;
 
@@ -447,9 +505,9 @@ int avahi_string_list_get_pair(AvahiStringList *l, char **key, char **value, siz
                 return -1;
 
         e++; /* Advance after '=' */
-        
+
         n = l->size - (e - (char*) l->text);
-        
+
         if (value) {
 
             if (!(*value = avahi_memdup(e, n+1))) {
@@ -487,7 +545,7 @@ uint32_t avahi_string_list_get_service_cookie(AvahiStringList *l) {
     AvahiStringList *f;
     char *value = NULL, *end = NULL;
     uint32_t ret;
-    
+
     if (!(f = avahi_string_list_find(l, AVAHI_SERVICE_COOKIE)))
         return AVAHI_SERVICE_COOKIE_INVALID;
 
@@ -502,6 +560,6 @@ uint32_t avahi_string_list_get_service_cookie(AvahiStringList *l) {
     }
 
     avahi_free(value);
-    
+
     return ret;
 }
