@@ -1,18 +1,16 @@
-/* $Id: unsupported.c 1274 2006-08-25 18:45:17Z lennart $ */
-
 /***
   This file is part of avahi.
- 
+
   avahi is free software; you can redistribute it and/or modify it
   under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 2.1 of the
   License, or (at your option) any later version.
- 
+
   avahi is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
   Public License for more details.
- 
+
   You should have received a copy of the GNU Lesser General Public
   License along with avahi; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
@@ -43,22 +41,7 @@ DNSServiceErrorType DNSSD_API DNSServiceRegisterRecord (
     AVAHI_GCC_UNUSED void *context) {
 
     AVAHI_WARN_UNSUPPORTED;
-    
-    return kDNSServiceErr_Unsupported;
-}
 
-DNSServiceErrorType DNSSD_API DNSServiceQueryRecord (
-    AVAHI_GCC_UNUSED DNSServiceRef *sdRef,
-    AVAHI_GCC_UNUSED DNSServiceFlags flags,
-    AVAHI_GCC_UNUSED uint32_t interfaceIndex,
-    AVAHI_GCC_UNUSED const char *fullname,
-    AVAHI_GCC_UNUSED uint16_t rrtype,
-    AVAHI_GCC_UNUSED uint16_t rrclass,
-    AVAHI_GCC_UNUSED DNSServiceQueryRecordReply callBack,
-    AVAHI_GCC_UNUSED void *context) {
-
-    AVAHI_WARN_UNSUPPORTED;
-    
     return kDNSServiceErr_Unsupported;
 }
 
@@ -72,13 +55,13 @@ DNSServiceErrorType DNSSD_API DNSServiceReconfirmRecord (
     AVAHI_GCC_UNUSED const void *rdata) {
 
     AVAHI_WARN_UNSUPPORTED;
-    
+
     return kDNSServiceErr_Unsupported;
 }
 
 DNSServiceErrorType DNSSD_API DNSServiceCreateConnection(AVAHI_GCC_UNUSED DNSServiceRef *sdRef) {
     AVAHI_WARN_UNSUPPORTED;
-    
+
     return kDNSServiceErr_Unsupported;
 }
 
@@ -92,7 +75,7 @@ DNSServiceErrorType DNSSD_API DNSServiceAddRecord(
     AVAHI_GCC_UNUSED uint32_t ttl) {
 
     AVAHI_WARN_UNSUPPORTED;
-    
+
     return kDNSServiceErr_Unsupported;
 }
 
@@ -102,8 +85,6 @@ DNSServiceErrorType DNSSD_API DNSServiceRemoveRecord(
     AVAHI_GCC_UNUSED DNSServiceFlags flags) {
 
     AVAHI_WARN_UNSUPPORTED;
-    
+
     return kDNSServiceErr_Unsupported;
 }
-
-
